@@ -6,7 +6,9 @@ use warnings;
 our @ISA = qw();
 
 require v5.8.1;
-use version; our $VERSION = version->declare('v0.0.0_1');
+use version; our $VERSION = version->declare('v0.0.0_2');
+
+use constant CRLF => qq[\015\012];
 
 require WARC::Volume;
 require WARC::Collection;
@@ -49,24 +51,28 @@ classes are available.
 
 =over
 
-=item WARC::Collection
+=item L<WARC::Collection>
 
 A C<WARC::Collection> object represents a set of indexed WARC files.
 
-=item WARC::Volume
+=item L<WARC::Volume>
 
 A C<WARC::Volume> object represents a single WARC file.
 
-=item WARC::Record
+=item L<WARC::Record>
 
 Each record in a WARC volume is analogous to an C<HTTP::Message>, with
 headers specific to the WARC format.
 
-=item WARC::Record::Payload
+=item L<WARC::Record::Payload>
 
-=item WARC::Record::Segment
+Planned support for tied filehandles reading WARC payloads.
 
-=item WARC::Fields
+=item L<WARC::Record::Segment>
+
+Planned support class for handling WARC segmentation.
+
+=item L<WARC::Fields>
 
 A C<WARC::Fields> object represents the set of headers in a WARC record,
 analogous to the use of C<HTTP::Headers> with C<HTTP::Message>.  The
@@ -79,24 +85,24 @@ The key-value format used in WARC headers has its own MIME type
 "warcinfo" record and elsewhere.  The C<WARC::Fields> class also provides
 support for objects of this type.
 
-=item WARC::Index
+=item L<WARC::Index>
 
 C<WARC::Index> is the base class for WARC index formats and also holds a
 registry of loaded index formats for convenience when assembling
 C<WARC::Collection> objects.
 
-=item WARC::Index::File::CDX
+=item L<WARC::Index::File::CDX>
 
 Access module for the common CDX WARC index format.
 
-=item WARC::Index::File::SDBM
+=item L<WARC::Index::File::SDBM>
 
 Planned "fast index" format using "SDBM_File" to index multiple CDX indexes
 for fast lookup by URL/timestamp pairs.  Planned because sdbm is included
 with Perl and the 1008 byte record limit should be a minor problem by
 storing URL prefixes and splitting records.
 
-=item WARC::Index::File::SQLite
+=item L<WARC::Index::File::SQLite>
 
 Another planned "fast index" format using DBI and DBD::SQLite.  This module
 avoids the limitations of SDBM, but depends on modules from CPAN.
@@ -107,15 +113,15 @@ avoids the limitations of SDBM, but depends on modules from CPAN.
 
 =over
 
-=item WARC::Volume::Builder
+=item L<WARC::Builder>
 
-The C<WARC::Volume::Builder> class provides a means to write new WARC files.
+The C<WARC::Builder> class provides a means to write new WARC files.
 
-=item WARC::Index::File::CDX::Builder
+=item L<WARC::Index::File::CDX::Builder>
 
-=item WARC::Index::File::SDBM::Builder
+=item L<WARC::Index::File::SDBM::Builder>
 
-=item WARC::Index::File::SQLite::Builder
+=item L<WARC::Index::File::SQLite::Builder>
 
 The C<WARC::Index::File::*::Builder> classes provide tools for building
 indexes either incrementally while writing the corresponding WARC file or
@@ -128,6 +134,9 @@ classes for the actual work.
 
 =head1 CAVEATS
 
+Support for the RFC 2047 "encoded-words" mechanism is required by the WARC
+specification but not yet implemented.
+
 Support for WARC record segmentation is planned but not yet implemented.
 
 Handling segmented WARC records requires using the C<WARC::Collection>
